pub struct WsClientBuilder { /* private fields */ }
Builder for WsClient.

Examples


use jsonrpsee_ws_client::{WsClientBuilder, HeaderMap, HeaderValue};

#[tokio::main]
async fn main() {
    // Build custom headers used during the handshake process.
    let mut headers = HeaderMap::new();
    headers.insert("Any-Header-You-Like", HeaderValue::from_static("42"));

    // Build client
    let client = WsClientBuilder::default()
         .set_headers(headers)
         .build("wss://localhost:443")
         .await
         .unwrap();

    // use client....
}

Implementations

source

impl WsClientBuilder

source

pub fn new() -> WsClientBuilder

Create a new WebSocket client builder.

source

pub fn use_native_rustls(self) -> WsClientBuilder

Force to use the rustls native certificate store.

Since multiple certificate stores can be optionally enabled, this option will force the native certificate store to be used.

This is enabled with the default settings and features.

Optional

This requires the optional native-tls feature.

source

pub fn max_request_size(self, size: u32) -> WsClientBuilder

See documentation WsTransportClientBuilder::max_request_size (default is 10 MB).

source

pub fn max_response_size(self, size: u32) -> WsClientBuilder

See documentation WsTransportClientBuilder::max_response_size (default is 10 MB).

source

pub fn request_timeout(self, timeout: Duration) -> WsClientBuilder

See documentation ClientBuilder::request_timeout (default is 60 seconds).

source

pub fn connection_timeout(self, timeout: Duration) -> WsClientBuilder

See documentation WsTransportClientBuilder::connection_timeout (default is 10 seconds).

source

pub fn enable_ws_ping(self, cfg: PingConfig) -> WsClientBuilder

See documentation ClientBuilder::enable_ws_ping (disabled by default).

source

pub fn disable_ws_ping(self) -> WsClientBuilder

source

pub fn set_headers(self, headers: HeaderMap) -> WsClientBuilder

See documentation WsTransportClientBuilder::set_headers (default is none).

source

pub fn max_concurrent_requests(self, max: usize) -> WsClientBuilder

See documentation ClientBuilder::max_concurrent_requests (default is 256).

source

pub fn max_buffer_capacity_per_subscription(self, max: usize) -> WsClientBuilder

See documentation ClientBuilder::max_buffer_capacity_per_subscription (default is 1024).

source

pub fn max_redirections(self, redirect: usize) -> WsClientBuilder

See documentation WsTransportClientBuilder::max_redirections (default is 5).

source

pub fn id_format(self, kind: IdKind) -> WsClientBuilder

See documentation for ClientBuilder::id_format (default is Number).

source

pub fn set_max_logging_length(self, max: u32) -> WsClientBuilder

Set maximum length for logging calls and responses.

Logs bigger than this limit will be truncated.

source

pub fn set_tcp_no_delay(self, no_delay: bool) -> WsClientBuilder

See documentation ClientBuilder::set_tcp_no_delay (default is true).

source

pub fn build_with_transport<S, R>(self, sender: S, receiver: R) -> Client

Build the WsClient with specified TransportSenderT TransportReceiverT parameters

Panics

Panics if being called outside of tokio runtime context.

source

pub async fn build_with_stream<T>( self, url: impl AsRef<str>, data_stream: T ) -> Result<Client, Error>
where T: AsyncRead + AsyncWrite + Unpin + MaybeSend + 'static,

Build the WsClient with specified data stream, using WsTransportClientBuilder::build_with_stream.

Panics

Panics if being called outside of tokio runtime context.

source

pub async fn build(self, url: impl AsRef<str>) -> Result<Client, Error>

Build the WsClient with specified URL to connect to, using the default WsTransportClientBuilder::build_with_stream, therefore with the default TCP as transport layer.

Panics

Panics if being called outside of tokio runtime context.